# Welcome to the Blue API Python SDK

This SDK is designed to facilitate interaction with the Blue API, enabling you to use Blue API endpoints in your Python projects.

We are using `sgqlc` to generate the GraphQL client so that we can use the Blue API in a type-safe manner and that there is a 100% coverage of the API which includes:

-  ~100 queries
-  ~200 mutations
-  ~400+ objects

If you have specific helpers for endpoints in mind that you'd like to see added, please let us know at <help@blue.cc> and we'll do our best to prioritize them to make it easier to manage your Blue environment programmatically.

You can install the package using pip:

```bash
pip install bluepm
```

Stay Productive,

Team Blue